Linear Algebra
==============

``bewegung`` offers a number of *convenience* classes for tasks related to linear algebra. They are isolated into a distinct sub-module named ``bewegung.linalg``.

.. note::

    The classes provided here are neither very performant nor feature-complete.

.. toctree::
   :maxdepth: 2
   :caption: The API in detail

   vectors
   matrices
   camera
